<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * ShortCodes
 *
 * @Version 0.8
 * @author Eugeny Panikarowsky - evgenii_panikaro@mail.ru
 * @copyright © 2015 Eugeny Panikarowsky
 *
*/

class ShortCode_Controller_Edit extends Admin_Form_Action_Controller_Type_Edit
{

	/**
	 * Set object
	 * @param $object object
	 * @return self
	 */
	public function setObject($object)
	{
		
		$windowId = $this->_Admin_Form_Controller->getWindowId();

		parent::setObject($object);
		
		$this->addMessage(
			Core_Message::get(Core::_('shortcode.attention'), 'error')
		);

		$oMainTab = $this->getTab('main');
		$oMainTab->delete($this->getField('site_id'));
		$oMainTab->delete($this->getField('active'));

		$site_id = $this->getField('site_id');
		if (!$site_id->value) {
			$site_id->value(CURRENT_SITE);
		}
		
		$oAdmin_Form_Entity_Textarea_Lib_Config = Admin_Form_Entity::factory('Textarea');
		$oAdmin_Form_Entity_Textarea_Lib_Config
				->value(
					$this->_object->loadShortCodeFile()
				)
				->cols(140)
				->rows(30)
				->class('php_code')
				->id('php_code')
				->caption(Core::_('shortcode.shortcode_code'))
				->name('php_code');

		$oMainTab->add($oAdmin_Form_Entity_Textarea_Lib_Config);
		$site_id->type('hidden');
		
		$oMainTab->add($this->getField('active'));

		$oAdditionalTab = $this->getTab('additional');
		
		$oAdditionalTab->active(0);

		$oAdditionalTab->add($site_id);
		
		$this->title(
			$this->_object->id
				? Core::_('shortcode.edit_title')
				: Core::_('shortcode.add_title'));

		return $this;
	}
	
	/**
	 * Processing of the form. Apply object fields.
	 */
	protected function _applyObjectProperty()
	{
		parent::_applyObjectProperty();
		
		$this->_object->saveShortCodeFile(Core_Array::getRequest('php_code'));

	}
	
	/**
	 * Executes the business logic.
	 * @param mixed $operation Operation name
	 * @return self
	 */
	public function execute($operation = NULL) {
		$tag = Core_Array::getPost('tag');
		$oSameShortCode = Core_Entity::factory('shortcode');
                $oSameShortCode->queryBuilder()
                        ->where('tag', '=', $tag)
                        ->where('site_id', '=', CURRENT_SITE);
                $oSameShortCode =  $oSameShortCode->find();
		if (!is_null($oSameShortCode) && $oSameShortCode->id != Core_Array::getPost('id'))
		{
			$this->addMessage(Core_Message::get(Core::_('shortcode.error_shortcode_tag'), 'error'));
			return TRUE;
		}
		return parent::execute($operation);
	}
}