<?php

defined('HOSTCMS') || exit('HostCMS: access denied.');

/**
 * ShortCodes
 *
 * @Version 0.8
 * @author Eugeny Panikarowsky - evgenii_panikaro@mail.ru
 * @copyright © 2015 Eugeny Panikarowsky
 *
*/
class ShortCode_Module extends Core_Module
{
	
	protected $_modulePath = 'shortcode';
	
	protected $_userID = NULL;
	
	protected $_adminpath = 'admin/shortcode/';
	
	protected $_observers = '$shortcode = CMS_FOLDER . "modules/shortcode/observer.php"; if (file_exists($shortcode)) { require_once($shortcode);}';
	
	protected $_langs = array();
	/**
	 * Module version
	 * @var string
	 */
	public $version = '0.6';

	/**
	 * Module date
	 * @var date
	 */
	public $date = '2014-05-22';
	
	protected function _checkLng($lng) {

		$aPath = explode('_', $this->_modulePath);

		$path = Core::$modulesPath;

		$path .= implode(DIRECTORY_SEPARATOR, $aPath) . DIRECTORY_SEPARATOR;

		$path .= 'i18n' . DIRECTORY_SEPARATOR . $lng . '.php';

		$path = Core_File::pathCorrection($path);
		
		if (is_file($path)) {
			return true;
		}
		return false;

	}
	
	protected function _getLangs() {
		$aAdmin_Languages = Core_Entity::factory('Admin_Language')->findAll();
		$this->_langs = $aAdmin_Languages;
		return $this;
	}	
	
	public function addField(array $param) {

		$oAdmin_Form_Field = Core_Entity::factory('Admin_Form_Field');
		
		$oAdmin_Form_Field->name			= $param['name'];
		$oAdmin_Form_Field->type			= isset($param['type'])? $param['type']: 1;
		$oAdmin_Form_Field->sorting			= isset($param['sorting'])? $param['sorting']: 0;
		$oAdmin_Form_Field->allow_sorting	= isset($param['allow_sorting'])? $param['allow_sorting']: 0;
		$oAdmin_Form_Field->allow_filter	= isset($param['allow_filter'])? $param['allow_filter']: 0;
		$oAdmin_Form_Field->editable		= isset($param['editable'])? $param['editable']: 0;
		$oAdmin_Form_Field->filter_type		= isset($param['filter_type'])? $param['filter_type']: 0;
		$oAdmin_Form_Field->user_id			= $this->_userID;
		$oAdmin_Form_Field->title_align		= isset($param['title_align'])? $param['title_align']: '';
		$oAdmin_Form_Field->align			= isset($param['align'])? $param['align']: '';
		$oAdmin_Form_Field->width			= isset($param['width'])? $param['width']: '';
		$oAdmin_Form_Field->style			= isset($param['style'])? $param['style']: '';
		$oAdmin_Form_Field->attributes		= isset($param['attributes'])? $param['attributes']: '';
		$oAdmin_Form_Field->image			= isset($param['image'])? $param['image']: '';
		$oAdmin_Form_Field->link			= isset($param['link'])? $param['link']: '';
		$oAdmin_Form_Field->onclick			= isset($param['onclick'])? $param['onclick']: '';
		$oAdmin_Form_Field->list			= isset($param['list'])? $param['list']: '';
		$oAdmin_Form_Field->admin_form_id	= $param['admin_form_id'];
		$oAdmin_Form_Field->save();
		if (!empty($this->_langs))
		{
			$oAdmin_Word = Core_Entity::factory('Admin_Word');
			foreach ($this->_langs as $oAdmin_Language)
			{
				$name = $description = '';
				if ($this->_checkLng($oAdmin_Language->shortname)) {
					if (isset($param['wordname'])) {
						$name = Core_I18n::instance()->get("{$param['wordname']}", $oAdmin_Language->shortname);
					}
					if (isset($param['worddescription'])) {
						$description = Core_I18n::instance()->get("{$param['worddescription']}", $oAdmin_Language->shortname);
					}
					
					$oAdmin_Word_Value = Core_Entity::factory('Admin_Word_Value');
					$oAdmin_Word_Value->admin_language_id = $oAdmin_Language->id;
	
					$oAdmin_Word_Value->name = $name;
					$oAdmin_Word_Value->description = $description;
					$oAdmin_Word_Value->save();
					$oAdmin_Word->add($oAdmin_Word_Value);
	
				}
			}
			$oAdmin_Form_Field->add($oAdmin_Word);
		}
		return $oAdmin_Form_Field;
	}
	
	public function addForm(array $param) {

		$oAdmin_Form = Core_Entity::factory('Admin_Form');

		$oAdmin_Form->on_page					= isset($param['on_page'])					? $param['on_page']					: 20;
		$oAdmin_Form->key_field					= isset($param['key_field'])				? $param['key_field']				: '';
		$oAdmin_Form->show_operations			= isset($param['show_operations'])			? $param['show_operations']			: 0;
		$oAdmin_Form->show_group_operations		= isset($param['show_group_operations'])	? $param['show_group_operations']	: 0;
		$oAdmin_Form->default_order_field		= isset($param['default_order_field'])		? $param['default_order_field']		: 'id';
		$oAdmin_Form->default_order_direction	= isset($param['default_order_direction'])	? $param['default_order_direction']	: 0;
		$oAdmin_Form->user_id					= $this->_userID;
		$oAdmin_Form->save();
		
		if (!empty($this->_langs))
		{
			$oAdmin_Word = Core_Entity::factory('Admin_Word');
			foreach ($this->_langs as $oAdmin_Language)
			{

				if ($this->_checkLng($oAdmin_Language->shortname)) {
					if (isset($param['wordname'])) {
						$name = Core_I18n::instance()->get("{$param['wordname']}", $oAdmin_Language->shortname);
					}
					if (isset($param['worddescription'])) {
						$description = Core_I18n::instance()->get("{$param['worddescription']}", $oAdmin_Language->shortname);
					}
					
					$oAdmin_Word_Value = Core_Entity::factory('Admin_Word_Value');
					$oAdmin_Word_Value->admin_language_id = $oAdmin_Language->id;
	
					$oAdmin_Word_Value->name = $name;
					$oAdmin_Word_Value->description = $description;
					$oAdmin_Word_Value->save();
					$oAdmin_Word->add($oAdmin_Word_Value);
	
				}
			}
			$oAdmin_Form->add($oAdmin_Word);
		}
		
		$oAdmin_Form->save();
		return $oAdmin_Form;
	}
	
	public function addAction(array $param) {
		
		$oAdmin_Form_Action = Core_Entity::factory('Admin_Form_Action');
		
		$oAdmin_Form_Action->admin_form_id	= $param['admin_form_id'];
		$oAdmin_Form_Action->name			= $param['name'];
		$oAdmin_Form_Action->picture		= isset($param['picture'])? $param['picture']: 1;
		$oAdmin_Form_Action->single			= isset($param['single'])? $param['single']: 1;
		$oAdmin_Form_Action->group			= isset($param['group'])? $param['group']: 0;
		$oAdmin_Form_Action->sorting		= isset($param['sorting'])? $param['sorting']: 0;
		$oAdmin_Form_Action->dataset		= isset($param['dataset'])? $param['dataset']: -1;
		$oAdmin_Form_Action->confirm		= isset($param['confirm'])? $param['confirm']: 0;
		$oAdmin_Form_Action->user_id		= $this->_userID;
		$oAdmin_Form_Action->save();

		if (!empty($this->_langs))
		{
			$oAdmin_Word = Core_Entity::factory('Admin_Word');
			foreach ($this->_langs as $oAdmin_Language)
			{
				$name = $description = '';

				if ($this->_checkLng($oAdmin_Language->shortname)) {
					if ( isset($param['wordname']) ) {
						$name = Core_I18n::instance()->get("{$param['wordname']}", $oAdmin_Language->shortname);
					}
					if ( isset($param['worddescription']) ) {
						$description = Core_I18n::instance()->get("{$param['worddescription']}", $oAdmin_Language->shortname);
					}
					
					
					$oAdmin_Word_Value = Core_Entity::factory('Admin_Word_Value');
					$oAdmin_Word_Value->admin_language_id = $oAdmin_Language->id;
	
					$oAdmin_Word_Value->name = $name;
					$oAdmin_Word_Value->description = $description;
					$oAdmin_Word_Value->save();
					$oAdmin_Word->add($oAdmin_Word_Value);
	
				}
			}
			$oAdmin_Form_Action->add($oAdmin_Word);
		}
	}

	public function install() {
		$this->_getLangs();
		
		// прописываем хуки
		$text = Core_File::read(CMS_FOLDER.'bootstrap.php');
		if (strpos($text, $this->_observers) == 0)
		{
			$fp = fopen( CMS_FOLDER.'bootstrap.php', 'a');
			fwrite($fp, "\n\r".$this->_observers);
			fclose($fp);
		}
		
		$oUserCurrent = Core_Entity::factory('User', 0)->getCurrent();
		$this->_userID = is_null($oUserCurrent) ? 0 : $oUserCurrent->id;
		
		
		/* создаем формы редактирования */
		
			// Редиректы: Список редиректов
			$actionpath = CMS_FOLDER . $this->_adminpath.'index.php';
			
			
			$param = array('wordname'=>'shortcode.shortcodelist','worddescription'=>'',	'on_page'=>20, 'key_field'=>'id', 'show_operations'=>1, 'show_group_operations'=>1,'default_order_field'=>'id', 'default_order_direction'=>1	);
			$oAdmin_Form = $this->addForm($param);
			
			/* Создаем поля */
		
				// Поле Код	
				$param = array( 'admin_form_id'=>$oAdmin_Form->id, 'width'=>'40px' ,'align'=>'left','title_align'=>'left','name'=>'id', 'type'=>1, 'allow_filter'=>1, 'allow_sorting'=>1,'sorting'=>5,'wordname'=>'shortcode.id');
				$this->addField($param);
				
				// Поле IMG
				$param = array( 'admin_form_id'=>$oAdmin_Form->id,'name'=>'img','sorting'=>10,'type'=>7,'format'=>'','allow_sorting'=>0,'allow_filter'=>0,'editable'=>0,'filter_type'=>0,'title_align'=>'center','align'=>'left','width'=>'16px','style'=>'widht: 16px;','attributes'=>'','image'=>"0=/admin/images/folder.gif\r\n1=/admin/images/page.gif",'link'=>'','onclick'=>'','list'=>'');
				$this->addField($param);
				
				// Поле Название
				$param = array( 'admin_form_id'=>$oAdmin_Form->id,'name'=>'name','sorting'=>20,'type'=>1,'format'=>'','allow_sorting'=>0,'allow_filter'=>0,'editable'=>0,'filter_type'=>0,'title_align'=>'left','align'=>'left','width'=>'300px','style'=>'','attributes'=>'','image'=>'','list'=>'','wordname'=>'shortcode.name', 'worddescription'=>'');
				$this->addField($param);
				
				// Поле Тэг
				$param = array( 'admin_form_id'=>$oAdmin_Form->id,'name'=>'tag','sorting'=>30,'type'=>1,'format'=>'','allow_sorting'=>0,'allow_filter'=>0,'editable'=>0,'filter_type'=>0,'title_align'=>'left','align'=>'left','width'=>'','style'=>'','attributes'=>'','image'=>'','list'=>'','wordname'=>'shortcode.tag', 'worddescription'=>'');
				$this->addField($param);
				
				$param = array('admin_form_id'=>$oAdmin_Form->id,'name'=>'active','sorting'=>35,'type'=>7,'format'=>'','allow_sorting'=>0,'allow_filter'=>0,'editable'=>0,'filter_type'=>0,'title_align'=>'left','align'=>'center','width'=>'50px','style'=>'','attributes'=>'','image'=>"0 = /admin/images/not_check.gif\r\n1 = /admin/images/check.gif",'link'=>'/admin/shortcode/index.php?hostcms[action]=changeActive&hostcms[checked][0][{id}]=1','onclick'=>'$.adminLoad({path: \'/admin/shortcode/index.php\',additionalParams: \'hostcms[checked][0][{id}]=1\', action: \'changeActive\', windowId: \'{windowId}\'}); return false','list'=>'');
				$this->addField($param);

			
			/* Создаем действия */
			
				// Удалить
				$param = array('wordname'=>'shortcode.delete', 'worddescription'=>'', 'admin_form_id'=>$oAdmin_Form->id,'name'=>'markDeleted','picture'=>'/admin/images/delete.gif','single'=>1,'group'=>1,'sorting'=>30,'dataset'=>-1,'confirm'=>1);
				$this->addAction($param);
				// Редактировать
				$param = array('wordname'=>'shortcode.edit', 'worddescription'=>'','admin_form_id'=>$oAdmin_Form->id,'name'=>'edit','picture'=>'/admin/images/edit.gif','single'=>1,'group'=>0,'sorting'=>10,'dataset'=>-1,'confirm'=>0);
				$this->addAction($param);
				// Активность
				$param = array('wordname'=>'shortcode.active', 'worddescription'=>'', 'admin_form_id'=>$oAdmin_Form->id,'name'=>'changeActive','picture'=>'','single'=>0,'group'=>0,'sorting'=>0,'dataset'=>-1,'confirm'=>0);
				$this->addAction($param);
								
			
			$sAdminIndex = Core_File::read($actionpath);
			$sAdminIndex = str_replace('{form_shortcodelist_id}',$oAdmin_Form->id,$sAdminIndex);

			Core_File::write($actionpath,$sAdminIndex);

			$dumpfile = Core_File::read(dirname(__FILE__) . DIRECTORY_SEPARATOR .'install.sql');

			Sql_Controller::instance()->execute($dumpfile);
	}
	
	public function uninstall() {
	}

	/**
	 * Constructor.
	 */
	public function __construct()
	{
		parent::__construct();

		$this->menu = array(
			array(
				'sorting'=>30,
				'block'=>0,
				'name'=>Core::_('shortcode.menu'),
				'href'=>"/admin/shortcode/index.php",
				'onclick'=>"$.adminLoad({path: '/admin/shortcode/index.php'}); return false"
			)
		);
	}



}